summaryrefslogtreecommitdiffstats
path: root/qmake/generators/makefile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qmake/generators/makefile.cpp')
-rw-r--r--qmake/generators/makefile.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/qmake/generators/makefile.cpp b/qmake/generators/makefile.cpp
index 99b10d3e..c4c42343 100644
--- a/qmake/generators/makefile.cpp
+++ b/qmake/generators/makefile.cpp
@@ -94,7 +94,7 @@ static bool createDir(const TQString& fullPath)
MakefileGenerator::MakefileGenerator(TQMakeProject *p) : init_opath_already(FALSE),
- init_already(FALSE), moc_aware(FALSE),
+ init_already(FALSE), tqmoc_aware(FALSE),
no_io(FALSE), project(p)
{
}
@@ -545,7 +545,7 @@ MakefileGenerator::generateDependencies(TQPtrList<MakefileDependDir> &dirs, cons
}
}
}
- if( mocAware() && //is it a moc file?
+ if( tqmocAware() && //is it a moc file?
( inc.endsWith(Option::cpp_ext.first()) || inc.endsWith(Option::cpp_moc_ext) )
|| ( (Option::cpp_ext.first() != Option::h_moc_ext) && inc.endsWith(Option::h_moc_ext) )) {
TQString mocs[] = { TQString("_HDRMOC"), TQString("_SRCMOC"), TQString::null };
@@ -944,8 +944,8 @@ MakefileGenerator::init()
if(!found_cache_moc || !found_cache_dep)
write_cache = TRUE;
}
- /* Do moc before dependency checking since some includes can come from
- moc_*.cpp files */
+ /* Do tqmoc before dependency checking since some includes can come from
+ tqmoc_*.cpp files */
if(found_cache_moc) {
TQString fixed_file(fileFixify((*val_it), TQDir::currentDirPath(), Option::output_dir));
TQString moc = findMocDestination(fixed_file);
@@ -960,7 +960,7 @@ MakefileGenerator::init()
}
}
}
- } else if(mocAware() && (sources[x] == "SOURCES" || sources[x] == "HEADERS") &&
+ } else if(tqmocAware() && (sources[x] == "SOURCES" || sources[x] == "HEADERS") &&
(Option::qmake_mode == Option::QMAKE_GENERATE_PROJECT ||
Option::mkfile::do_mocs)) {
generateMocList((*val_it));
@@ -1199,7 +1199,7 @@ MakefileGenerator::init()
Option::output_dir));
//moc files
- if ( mocAware() ) {
+ if ( tqmocAware() ) {
if(!project->isEmpty("MOC_DIR"))
project->variables()["INCLUDEPATH"].append(project->first("MOC_DIR"));
if ( Option::h_moc_ext == Option::cpp_ext.first() )